#
# spec file for package ueberzugpp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define short_name ueberzug
Name:           ueberzugpp
Version:        2.9.6+git20241007.eea57da
Release:        1.4
Summary:        Utility to render images in terminals
License:        GPL-3.0
URL:            https://github.com/jstkdng/%{name}
Source:         https://github.com/jstkdng/%{name}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  automake
BuildRequires:  cmake
BuildRequires:  cmake(Microsoft.GSL)
BuildRequires:  cmake(range-v3)
BuildRequires:  cmake(spdlog)
BuildRequires:  extra-cmake-modules
BuildRequires:  gcc-c++
BuildRequires:  git-core
BuildRequires:  make
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(CLI11)
BuildRequires:  pkgconfig(chafa)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libsixel)
BuildRequires:  pkgconfig(nlohmann_json)
BuildRequires:  pkgconfig(opencv4)
BuildRequires:  pkgconfig(tbb)
BuildRequires:  pkgconfig(vips)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(xcb-image)

%description
Überzug++ is a C++ command line utility which allows to draw images
on terminals by using child windows or using sixel on supported
terminals. (This is a drop-in replacement for the now defunct
ueberzug project.)

Advantages over w3mimgdisplay and ueberzug:

- support for wayland (sway only)
- no race conditions as a new window is created to display images
- "expose" events will be processed, so that images will be
  redrawn when switching workspaces
- tmux support on X11
- terminals without the WINDOWID environment variable are supported
- chars are used as position and size unit
- A lot of image formats are supported (through opencv and libvips)
- GIF and animated WEBP support on X11 and Sixel
- Resized images are cached for faster viewing

%prep
%autosetup

%build
%cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} -DCMAKE_SKIP_RPATH=YES -DCMAKE_BUILD_TYPE=release -DENABLE_WLROOTS=ON
%cmake_build

%install
%cmake_install
rm -v %{buildroot}%{_mandir}/man1/ueberzug.1
ln -s %{_mandir}/man1/ueberzugpp.1 %{buildroot}%{_mandir}/man1/ueberzug.1

%files
%{_bindir}/%{short_name}
%{_bindir}/%{short_name}pp
%license LICENSE
%doc README.md
%{_mandir}/man1/%{short_name}.1%{?ext_man}
%{_mandir}/man1/%{short_name}pp.1%{?ext_man}

%changelog
* Thu Oct 17 2024 scott.bradnick@suse.com
- Update to version 2.9.6+git20241007.eea57da:
  * add ability to overridde default temporary directory
  * [README.md] add twitchez to the list of apps that support ueberzugpp
  * handle SIGHUP with signal handler
  * Mixed up variables
  * Fix when image scaling, would not check for max_width and max_height
  * Fix image not hiding when switching between tmux sessions
* Mon Aug  5 2024 Scott Bradnick <scott.bradnick@suse.com>
- Swapping in pkgconfig(libcrypto) for pkgconfig(botan-3) per suggestion of
  Andreas Stieger in https://build.opensuse.org/request/show/1191432
* Fri Aug  2 2024 scott.bradnick@suse.com
- Update to version 2.9.6+git20240730.415879b:
  * Set minimum CMake version to 3.21
  * scripts: fzf preview positioning fixed
* Fri Aug  2 2024 Scott Bradnick <scott.bradnick@suse.com>
- Updating to use pkgconfig(botan-3) vs. pkgconfig(botan-2)
* Mon Jun 10 2024 scott.bradnick@suse.com
- Update to version 2.9.6+git20240609.7051b04:
  * bump version
* Sat May 18 2024 scott.bradnick@suse.com
- Update to version 2.9.5+git20240518.c3fd1c7:
  * forgot string
  * handle open error
  * handle error when trying to open not existant pty
* Sat May 11 2024 scott.bradnick@suse.com
- Update to version 2.9.5+git20240511.46fb226:
  * default to chafa and crash if output is not supported
  * bump version
  * update for hyprland 0.40 socket path change
  * update dependencies
  * don't use std::endl
  * use std::filesystem
  * explicit string include
* Mon Apr 29 2024 scott.bradnick@suse.com
- Update to version 2.9.4+git20240406.986be28:
  * code cleanup
  * drop libexif and handle other orientation values
  * initial dbus files
  * add dbus flag
  * add jetbrains support
  * egl changes
  * don't pass mutex with shared_ptr
  * minimum cmake required is now 3.22
  * add CODE_OF_CONDUCT.md
* Mon Feb 26 2024 scott.bradnick@suse.com
- Update to version 2.9.4+git20240225.aa26e11:
  * update readme
  * handle exif errors
  * don't use semver tweak
  * naming changes
  * fix regression
  * don't use forward declares and naming changes
* Sun Feb 25 2024 scott.bradnick@suse.com
- Update to version 2.9.3+git20240225.42367f0:
  * handle exceptions
  * fix versioning and deps
  * fix tmux bug and be const correct
  * gracefully exit on x11/wayland server close
  * use range-v3 and fix process
  * bump version
  * add range-v3
  * add range-v3 dependency
  * don't use regex
  * process changes
  * remove gsl from scripts
  * use target_compile_definitions
  * check wsl
  * format changes
  * remove O_NONBLOCK
  * remove gsl dependency
  * performance improvements
  * cleanup os.hpp
  * simplify env retrieving and don't use daemon
  * handle bad values in stoi
  * use array instead of vector for sum calculation
  * don't create lambda for simple threads
  * don't use reinterpret_cast
  * pin wayland event versions
  * handle hyprland scaling
  * remove march flag
  * formatting changes
  * formatting changes
  * use new chafa 1.14 api
  * premultiply alpha values
  * fix scaling with libvips
  * better scaling handling
  * format changes
  * formatting changes
  * handle multimonitor scaling with sway
  * formatting changes
  * formatting changes
  * support rgb16 images on opencv
* Sun Jan 28 2024 scott.bradnick@suse.com
- Update to version 2.9.2+git20240122.b5d0022:
  * remove dead code
  * use clang for formatting
  * restore old code
  * support exif rotation
  * fix typo
  * change logging messages
  * copy env variables before using them
  * simplify wayland code
  * clarify minimum versions
  * handle existance of WINDOWID under wayland
  * Proper wayland scaling (#148)
  * docs: add command line to install required libs on ubuntu (#146)
  * check for any existing x11 atoms
  * don't throw exceptions on main and improve config file parsing
  * bump version
  * follow core guidelines and be more const correct
  * support kitty 0.30
  * updated readme
  * use pointer instead of const ref
  * refactor: add posix and mac compliance for example scripts (#121)
  * added flag to set the image center as origin (#114)
  * change art printing
  * bump version and dep release
  * fix compilation with internal spdlog 1.12
  * fix compilation with fmt 10.1.0 and spdlog 1.12
  * enable c compiler extensions
  * bump version
  * reduce c standard
  * logging changes
  * remove ranges header
  * use range-v3 under macos
  * don't create cache dir if user doesn't want cache
  * use xdg_cache_home if available
  * finish support wayfire
  * updated plugin
  * add wayfire plugin
  * wayland changes
  * Initial wayfire support (#104)
  * use weak_from_this
  * remove debug headers
  * docs: add new link of yazi (#102)
  * style changes
  * fix egl logging
  * send json commands using nlohmann-json
  * fix memory leaks when using tmux
  * fix wayland memory leak
  * fix number of args when opengl is disabled
  * don't reset egl util if opengl not enabled
  * more informative opengl error handling
  * don't try to use opengl unless requested
  * random changes
  * implement egl support for wayland
  * opengl refactoring
  * random opengl changes
  * cleanup code
  * naming changes
  * more changes to wayland egl
  * test opengl on wayland
  * flip images for opengl
  * initial egl implementation for x11
  * playing with opengl
  * add fedora packaging
  * bump version
  * update readme
  * sway cleanup and add wayland-egl to cmake
  * cleanup hyprland code
  * hyprland test
  * remove hyprland multimonitor checks
  * refactor hyprland config
  * read all data from hyprland socket after write
  * modernizing changes
  * clean up windows before disconnecting
  * test handle multimonitors with hyprland
  * change terminal flags
  * fix include guard
  * check for par_unseq instead of <execution>
  * replace <execution> verification
  * remove old terminal recognition code
  * test better terminal recognition
  * change header guard names
  * another const
  * explicit lambda capture and some more const
  * remove sway absolute moving
  * test multimonitor on wayland
  * minor changes
  * don't call virtual functions inside constructor
  * handle xcb screen_num
  * some more const
  * fix tmux hook crashing u++
  * use feature detection to test for std::execution support (#87)
  * restore old resize logic
  * simplify image resizing logic
  * remove iterm2 logging
  * erase before insert
  * add missing include
  * don't use string_view with nlohmann json
  * finish spdlog fwd
  * use spdlog fwd
  * don't copy json strings
  * use bound checking when querying json
  * some error handling
  * simplify xres reply processing
  * random changes
  * logging for stdout canvas
  * destroy canvas before destroying libvips
  * better handle multiple images
  * naming changes
  * atomic bool refactor
  * add tmux support to wayland
  * wayland code refactoring
  * properly use weak_ptr
  * implement multiple image support for wayland
  * simplify stdout canvas
  * bind egl to opengl
  * separate method call and test libressl fix
  * pass Image as shared_ptr
  * pass around mutex as a shared_ptr
  * add missing header
  * Add support for multiple images (#79)
  * add image.nvim
  * fix crash when draw/clear commands are issued quickly in wayland (#78)
  * prefer one time move commands over window rules in wayland sway/hyprland (#77)
  * update homebrew links
  * move brew script to tap
  * fix(brewfile): syntax (#75)
  * hide xcb-errors behind compile flag
  * use pkgconfig for xcb
  * final code cleanup before refactor
  * remove xlib interop, use vanilla xcb
  * cleanup x11 code
  * remove unused headers
  * restore mutex usage on x11 canvas
  * naming changes
  * fix bug when image has n-pages but not delay
  * alloc 32 bytes for each event
  * add some more debugging messages for x11 canvas
  * remove const from pointer
  * performance improvements for X11 canvas
  * improvements to terminal recognition and x11 windows
  * check if running tmux to get fallback x11 sizes
  * don't take into account incomplete windows
  * add ENABLE_OPENGL flag
  * don't process image afterwards
  * prepare for argb x11 windows
  * add more x11 debug messages
  * move window on redraw
  * use activewindow address instead of pid
  * change xcb-res name
  * use xcb-res extension for faster pid-window queries
  * add debugging messages for X11
  * use fallthrough
  * improve xcb error checking
  * opencv 4.7.0 added support for non-animated webps
  * example: img-fifo script (#66)
  * remove usage of shared_ptr should increase performance a bit
  * improve performance for unix socket
  * fix obs naming
  * fix obs file naming
  * use curl's basic auth
  * upload files to obs
  * generate tar and dsc file
  * add pacman flag
  * install git on workflow
  * add workflow name
  * add workflow
  * bump version
  * properly recognize active monitor under sway
  * handle multiple monitors on sway
  * improvements with image processing
  * reset pointer instead of reassignment
  * try to consume all events as soon as one arrives
  * remove funny defines
  * improve performance of X11 output
  * fix crash when receiving multiple commmands fast
  * better handle image processing
  * subtract monitor coordinates
  * take into account active monitor coordinates
  * share x11 connection with smart pointers
  * example: add img script (#59)
  * calculate terminal sizes on hyprland
  * add wayland logging
  * use daemon function
  * update README
  * fix symlink path
  * replace version in manpage
  * install manpage
  * fix manpage section
  * fix man install dir
  * install man and symlink with cmake
  * update debian files
  * simplify debian rules
  * update debian deps
  * update debian dependencies
  * add cli11 as a submodule for offline builds
  * add debian packaging files
  * logging changes
  * add repology
  * finish naming changes and update manpage
  * replace wlroots naming
  * generalize wayland support
  * rollback changes on benchmark function
  * fmt can't handle fast image switching
  * bump brew version
  * bump version and sixel changes
  * update README and fix regression
  * update README.md
  * don't crash on socket errors
  * add support for hyprland
  * fix issues with new naming
  * refactor code for hyprland support
  * update README.md and remove uuid dependency
  * position window properly when terminal has padding under sway canvas
  * fix sway window position
  * docs: add ueberzugpp manpage (1) (#51)
  * use common functions for reading terminal escape sequences
  * stop reading from fd after newline
  * fix immediate exit if stdin is not used
  * fix build on gsl < 4
  * handle poll events and add support for FreeBSD
  * test fix for closed/null stdin
  * bump homebrew to 2.8.5
  * bump version and update README
  * generate random app_id for each ueberzugpp instance under sway
  * simplify sway polling
  * add reusable functions for polling and reading from file descriptors
  * remove zmq dependency, use regular sockets
  * add sway support checking
  * implement gif support on sway canvas
  * don't use recursion for tree iteration
  * ensure ueberzgpp is being used with tmux hooks
  * handle tmux events on sway canvas
  * execute less ipc commands on every canvas init
  * don't start/stop wayland's event handler constantly
  * finish initial support for sway
  * send commands to sway socket
  * use maybe_unused
  * better wayland drawing
  * test wayland drawing control
  * basic image displaying under wayland
  * wayland modifications
  * explicitly link against librt for wayland
  * add missing header and require C compiler now
  * add uuid and wayland shm helper
  * register wayland shm and compositor
  * wayland testing
  * initial groundwork for wayland support
  * upgrade homebrew script
  * bump version
  * Final changes for 2.8.4 (#45)
  * Changes for v2.8.4 (#44)
* Thu Sep 21 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.9.2:
  * support kitty 0.30
  * improve code correctness
* Sun Aug 20 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.9.1:
  * Fix compilation errors on spdlog 1.12, fmt 10.x and turbo-base64
  * Bump internal dependencies versions
* Tue Aug  8 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.9.0:
  * opengl support for X11 and wayland
  * add support for MacOS 11 Big Sur
  * add support for wayfire (plugin required)
  * fix memory leak when using wayland and tmux
  * performance improvements for wayland
  * use `XDG_CACHE_HOME` when available
* Tue Jul 18 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.8.9:
  * support for multiple images being displayed at the same time, images with the same identifier will be replaced
  * improved terminal recognition (deeply nested terminals are recognized correctly)
  * improved image positioning under wayland
  * improved multimonitor support under wayland
  * improved tmux support under wayland
  * code modernizing and cleanup
  * libressl support
  * small x11 performance improvements
* Fri Jun 23 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.8.8:
  * use xcb-res for obtaining pid of windows
  * use xcb-errors for useful error logging (disabled by default)
  * fix syncronization issues and performance improvements for x11 canvas
  * improve terminal selection
  * fixes for hyprland
  * improve throughput of unix socket
* Sat Jun 10 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.8.7:
  * add debian packaging
  * replace layer output flag `wlroots` in favor of `wayland`: it now works with any wayland wms, but only sway and hyprland have proper window positioning, hopefully add support for other wms in the future
  * support multiple monitors under sway and hyprland
  * peformance improvements for X11 canvas
  * update documentation
  * add more features to cmake install
  * improve libvips and opencv code
* Tue May 30 2023 Scott Bradnick <scott.bradnick@suse.com>
- Adding necessary "BuildRequires" to support `-DENABLE_WLROOTS=ON` after talking
  with developer
* Mon May 29 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.8.6:
  * add support for hyprland
  * fix bugs with command input/polling
  * fix regression when selecting a pty
  * remove uuid dependency
* Fri May 26 2023 Jan Engelhardt <jengelh@inai.de>
- Update summary to not assume special context (reference to
  ueberzug).
- Compact main description and weed out grammar errors.
* Fri May 26 2023 Scott Bradnick <scott.bradnick@suse.com>
- Updating description
- Update to version 2.8.5:
  * Wayland Support (only under sway and sway based wms)
  * remove zmq/cppzmq dependency (doesn't play well with unix sockets)
  * simplify code
* Mon May 22 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.8.4:
  * code cleanup
  * improve performance for kitty and iterm2
  * simplify x11 and sixel canvas
  * add chafa canvas as a last resort canvas
  * minimum GCC version supported is 10.1
* Fri May 19 2023 Scott Bradnick <scott.bradnick@suse.com>
- Switching to traditional release vs. git release
* Tue May 16 2023 Scott Bradnick <scott.bradnick@suse.com>
- Switching to %%cmake macros
* Mon May 15 2023 scott.bradnick@suse.com
- Update to version 2.8.3+git20230515.df4e40f:
  * upgrade homebrew script
  * bump version and only add flags on debug builds
  * code cleanup
  * fix unused variable when opencv is disabled
  * use -Wall and fix recommendations
  * simpler signal handling and code cleanup
  * switch to using a singleton for accessing program configuration
  * code refactoring
* Sun May 14 2023 scott.bradnick@suse.com
- Update to version 2.8.2+git20230513.804060e:
  * fix iterm2 recognition
  * better logging, improved terminal detection and fix sixel bug
  * update README
  * handle terminal padding when running under tmux
  * code cleanup
  * remove some checks
  * util refactor
  * tmux handling
  * update fzf script
  * update lf script
  * take into account window padding on x11 canvas
  * update homebrew script
  * bump version
  * switch from uint64_t to size_t
  * fix build on macos
  * Bug fixes (#35)
  * follow audit guidelines
  * update homebrew
* Thu May 11 2023 scott.bradnick@suse.com
- Update to version 2.8.1+git20230511.9085896:
  * bump version
  * Code refactoring + bug fixes (#34)
  * add clang-tidy file
  * Update README.md
  * update README and remove image
  * improve homebrew script
  * update homebrew script
  * add sample gif
* Mon May  8 2023 scott.bradnick@suse.com
- Update to version 2.8.0+git20230507.b6cf910:
  * simplify homebrew script
  * follow homebrew audit guidelines
  * add homebrew script
  * try to download cppzmq if not present
  * update README
  * fix fzf script
  * bump version
  * better handle macos processes
  * cmake cleanup
  * remove action
  * use tbb on macos
  * open ttys
  * pidinfo fails for other user processes
  * test libproc
  * use stdout for now
  * add cppzmq
  * update
  * check sysctl
  * add macos workflow
  * small fix importing library
  * apple doesn't support execution policies
  * join threads just in case
  * switch from jthread to thread
  * extract required macro from library
  * switch from jthread to thread
  * fix cached images no longer being recognized by iterm2
  * update README.md
  * extract required macro from library
  * initial iterm2 support
  * fix lf script
  * improvements with cmd subcommand and add lf integration script
  * code cleanup and refactoring
  * update README
  * update README.md
  * parallellize kitty encoding
  * bump version
  * support cmake version 3.18
* Tue Apr 25 2023 scott.bradnick@suse.com
- Update to version 2.7.7+git20230425.63a3b72:
  * try to build third_part libraries if not installed
* Tue Apr 25 2023 scott.bradnick@suse.com
- Update to version 2.7.7+git20230424.527cc96:
  * hide turbo-base64 behind compiler flag
* Mon Apr 24 2023 scott.bradnick@suse.com
- Update to version 2.7.7+git20230424.a8d07a9:
  * test fetchcontent + new release
  * add ability to disable opencv or x11 at compile time
  * fix kitty not displaying image in certain cases
* Sat Apr 22 2023 scott.bradnick@suse.com
- Update to version 2.7.6+git20230421.0cccbe3:
  * bump version
  * synchronize main thread and drawing threads
  * add fzf integration script
  * add command flag
  * fix image scaling
* Sun Apr 16 2023 scott.bradnick@suse.com
- Update to version 2.7.5+git20230416.588af3b:
  * bump version
  * don't reset empty stringstream
  * restore cursor position with kitty
  * naming changes
  * sixel improvements
  * sixel improvements
  * verify if opencl is available
  * restore cache usage in opencv
  * initial support for additional image scalers
  * wezterm fixed its kitty support
* Thu Apr 13 2023 scott.bradnick@suse.com
- Update to version 2.7.4+git20230413.49df37b:
  * bump version
* Thu Apr 13 2023 scott.bradnick@suse.com
- Update to version 2.7.3+git20230412.b34360e:
  * clear canvas before using it again
  * some performance changes
  * update README.md
* Mon Apr  3 2023 scott.bradnick@suse.com
- Update to version 2.7.3+git20230403.d5fad31:
  * add no-opencv flag
  * limit libvips cache
  * respect no_cache flag with libvips
  * respect no_cache option with libvips
  * use only libvips
  * use opencv mainly again
  * add missing iniclude for older compilers
  * use resize instead of thumbnail_image
  * test libvips only
  * add no-cache flag
* Sat Mar 25 2023 scott.bradnick@suse.com
- Update to version 2.7.3+git20230324.4d09378:
  * add None install configuration
  * bump version
  * fix socket not being deleted
  * fix tmux regression
  * use smart pointers
  * using SIXEL_LARGE_LUM seems to improve performance
  * use ueberzugpp for files/directories
* Wed Mar 15 2023 scott.bradnick@suse.com
- Update to version 2.7.2+git20230315.fa5bef6:
  * bump version
  * add benchmark function
  * some code refactoring
  * Fix uninitialized read in X11Util::get_window_pid
  * Fix use of delete operator on result of malloc()
  * Add missing <thread> include to application.hpp
  * Fix make install
* Mon Mar 13 2023 scott.bradnick@suse.com
- Update to version 2.7.1+git20230312.b470797:
  * code cleaning
  * bump version and fix flags default
  * allow multiple instances of ueberzug to run at the same time
  * kitty validations, prepare for iterm2 canvas
* Fri Mar 10 2023 scott.bradnick@suse.com
- Update to version 2.7.0+git20230310.2c547ca:
  * update README.md
  * bump version
  * link to Crypto instead of SSL
  * handle parse errors and recognize more options
  * parse configuration file if exists
  * improve compatibility
  * code cleanup
  * use openssl instead of botan
  * test openssl for base64 encoding
  * improve kitty performance
  * better kitty recognition
  * initial kitty support
  * add kitty files
  * formatting issues
* Wed Mar  8 2023 scott.bradnick@suse.com
- Update to version 2.6.0+git20230308.97a5b80:
  * bug fixes
  * remove iostream
  * hard code sixel support for some terminals
  * change name of ESC
  * some changes
  * remove benchmarking code
  * only use opencl if required
  * use map instead of ifs
  * better tmux hook handling + functioning image cache
  * cache images properly
* Mon Mar  6 2023 scott.bradnick@suse.com
- Update to version 2.5.0+git20230306.39514c0:
  * update sample script
  * prepare for new outputs
  * fix pty selection regression
  * update README, plus performance enhancements
  * remove debug print
  * hide windows when tmux window changed
* Sun Mar  5 2023 scott.bradnick@suse.com
- Update to version 2.5.0+git20230305.c9478aa:
  * handle pane resizes
  * use unix sockets instead of tcp
  * correctly handle tmux hooks
  * register/unregister tmux hooks
  * better tcp handling v2
  * better tcp handling
  * send message to tcp on tmux hooks
  * add tmux hook subcommand
* Wed Mar  1 2023 scott.bradnick@suse.com
- Update to version 2.4.0+git20230227.fc36c72:
  * synchronize threads
  * rollback last commit
  * let each window handle it's own connection
  * better cli option handling
  * more optimizations for libvips
  * add license header
  * libvips optimizations
  * don't log twice
  * Don't crash on a failure to load an image
  * Handle status==off in tmux::get_statusbar_offset()
  * take in account vertical multine tmux statusbar
* Sat Feb 25 2023 scott.bradnick@suse.com
- Update to version 2.3.0+git20230225.39e38a8:
  * improve opencl
  * actually try to use opencl
  * add validations
  * bump patch
  * bump version
  * use references instead of shared_ptr
  * cleaning code
  * find control terminal correctly
  * some refactoring
  * bump version
  * update README.md
  * better backwards compatibility
  * docs: remove  symbol from Build section
* Fri Feb 24 2023 scott.bradnick@suse.com
- Update to version 2.2.0+git20230223.7c68553:
  * Update README.md
  * fix option not working
  * update README
  * handle more flags
  * add zmq dependency
  * don't save vips loader
* Thu Feb 23 2023 scott.bradnick@suse.com
- Update to version 2.1.0+git20230222.06779d3:
  * bump version
  * do less work on cached images
  * use a proper logger
* Wed Feb 22 2023 scott.bradnick@suse.com
- Update to version 2.0.0+git20230222.2be53a8:
  * new release
  * cache resized images
  * pass loader used to libvips image
  * use libvips for displaying gifs and animated webps
  * fix ueberzug window appearing in wrong positions
  * some refactoring
* Sun Feb 19 2023 scott.bradnick@suse.com
- Update to version 1.9.1+git20230218.7913178:
  * bump version
  * fix image not being redraw on expose events
  * bump version
  * create x11 windows the same size as the resized image
  * better image resizing
  * add versioning and some refactoring
  * fix type in README
  * new release
  * log program version
  * better sixel output
  * Update README.md
  * Update README.md
* Thu Feb 16 2023 scott.bradnick@suse.com
- Update to version 1.7.0+git20230216.f1b670c:
  * add some validations
  * resolving merge conflict
  * better sixel output
  * marked call operator of callable object "const"
  * Defaulted empty dtor, removed empty implementation.
  * defaulted empty dtor
  * defaulted empty dtor and removed implementation of it from source file
  * Removing unnecessary assignment of nullptr to unique_ptr members in in-class initializer.
  * Removed extraneous semicolons, defaulted dtor implementation. Added .vs temporaries directory to git ignore.
  * better sixel support
  * don't use printf
* Tue Feb 14 2023 scott.bradnick@suse.com
- Update to version 1.6.0+git20230214.f016a6f:
  * complete gif support for sixel
  * test sixel gif support
* Mon Feb 13 2023 scott.bradnick@suse.com
- Update to version 1.5.0+git20230213.ab00bf2:
  * better image format handling
  * update README.md
  * add gif support to x11 canvas
  * prepare gif support
  * don't overlap with borders
  * bug fixing
  * update README.md
  * remove comments
  * cleaning
